@@ -22,12 +22,18 @@ class Patient(BaseTable):
         """
         Initialize the patient table.
         
-        Parameters:
-            data_directory (str): Path to the directory containing data files
-            filetype (str): Type of data file (csv, parquet, etc.)
-            timezone (str): Timezone for datetime columns
-            output_directory (str, optional): Directory for saving output files and logs
-            data (pd.DataFrame, optional): Pre-loaded data to use instead of loading from file
+        Parameters
+        ----------
+        data_directory : str
+            Path to the directory containing data files
+        filetype : str
+            Type of data file (csv, parquet, etc.)
+        timezone : str
+            Timezone for datetime columns
+        output_directory : str, optional
+            Directory for saving output files and logs
+        data : pd.DataFrame, optional
+            Pre-loaded data to use instead of loading from file
         """
    
         super().__init__(
